@@ -1,7 +1,10 @@
 import contextlib
+import pathlib
 import shlex
 import sys
 
+import importlib_resources as resources
+
 import toml
 from jaraco.context import suppress
 from jaraco.functools import apply
@@ -19,16 +22,23 @@ def none_as_empty(ob):
     return ob or {}
 
 
-@apply(none_as_empty)
-@suppress(Exception)
-def read_plugins(filename):
-    with open(filename, encoding='utf-8') as strm:
-        defn = toml.load(strm)
+def read_plugins_stream(stream):
+    defn = toml.load(stream)
     return defn["tool"]["pytest-enabler"]
 
 
+@apply(none_as_empty)
+@suppress(Exception)
+def read_plugins(path):
+    with path.open(encoding='utf-8') as stream:
+        return read_plugins_stream(stream)
+
+
 def pytest_load_initial_conftests(early_config, parser, args):
-    plugins = read_plugins('pyproject.toml')
+    plugins = {
+        **read_plugins(resources.files().joinpath('default.toml')),
+        **read_plugins(pathlib.Path('pyproject.toml')),
+    }
 
     def _has_plugin(name):
         pm = early_config.pluginmanager
@@ -64,11 +74,17 @@ def _pytest_cov_check(plugins, early_config, parser, args):  # pragma: nocover
     """
     if 'cov' not in plugins:
         return
+
+    if early_config.pluginmanager.getplugin('_cov'):
+        # cov was explicitly configured (#8)
+        return
+
     _remove_deps()
     # important: parse all known args to ensure pytest-cov can configure
     # itself based on other plugins like pytest-xdist (see #1).
     parser.parse_known_and_unknown_args(args, early_config.known_args_namespace)
+
     with contextlib.suppress(ImportError):
         import pytest_cov.plugin
 
-        pytest_cov.plugin.pytest_load_initial_conftests(early_config, parser, args)
+    pytest_cov.plugin.pytest_load_initial_conftests(early_config, parser, args)
